@@ -55,6 +55,8 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include "plasmavirtualdesktop_interface.h"
 #include "xdgoutput_interface.h"
 #include "xdgdecoration_interface.h"
+#include "eglstream_controller_interface.h"
+#include "keystate_interface.h"
 
 #include <QCoreApplication>
 #include <QDebug>
@@ -84,6 +86,7 @@ public:
     wl_event_loop *loop = nullptr;
     QString socketName = QStringLiteral("wayland-0");
     bool running = false;
+    bool automaticSocketNaming = false;
     QList<OutputInterface*> outputs;
     QList<OutputDeviceInterface*> outputdevices;
     QVector<SeatInterface*> seats;
@@ -161,13 +164,39 @@ QString Display::socketName() const
     return d->socketName;
 }
 
+void Display::setAutomaticSocketNaming(bool automaticSocketNaming)
+{
+    if (d->automaticSocketNaming == automaticSocketNaming) {
+        return;
+    }
+    d->automaticSocketNaming = automaticSocketNaming;
+    emit automaticSocketNamingChanged(automaticSocketNaming);
+}
+
+bool Display::automaticSocketNaming() const
+{
+    return d->automaticSocketNaming;
+}
+
 void Display::start(StartMode mode)
 {
     Q_ASSERT(!d->running);
     Q_ASSERT(!d->display);
     d->display = wl_display_create();
     if (mode == StartMode::ConnectToSocket) {
-        if (wl_display_add_socket(d->display, qPrintable(d->socketName)) != 0) {
+        if (d->automaticSocketNaming) {
+            const char *socket = wl_display_add_socket_auto(d->display);
+            if (socket == nullptr) {
+                qCWarning(KWAYLAND_SERVER) << "Failed to create Wayland socket";
+                return;
+            }
+
+            const QString newEffectiveSocketName = QString::fromUtf8(socket);
+            if (d->socketName != newEffectiveSocketName) {
+                d->socketName = newEffectiveSocketName;
+                emit socketNameChanged(d->socketName);
+            }
+        } else if (wl_display_add_socket(d->display, qPrintable(d->socketName)) != 0) {
             qCWarning(KWAYLAND_SERVER) << "Failed to create Wayland socket";
             return;
         }
@@ -487,6 +516,20 @@ XdgDecorationManagerInterface *Display::createXdgDecorationManager(XdgShellInter
     return d;
 }
 
+EglStreamControllerInterface *Display::createEglStreamControllerInterface(QObject *parent)
+{
+    EglStreamControllerInterface *e = new EglStreamControllerInterface(this, parent);
+    connect(this, &Display::aboutToTerminate, e, [e] { delete e; });
+    return e;
+}
+
+KeyStateInterface *Display::createKeyStateInterface(QObject *parent)
+{
+    auto d = new KeyStateInterface(this, parent);
+    connect(this, &Display::aboutToTerminate, d, [d] { delete d; });
+    return d;
+}
+
 void Display::createShm()
 {
     Q_ASSERT(d->display);
